@@ -241,11 +241,11 @@ class XbrlInstance(abc.ABC):
         return "{} with {} facts".format(self.instance_url, len(self.facts))
 
 
-def parse_xbrl_instance(cache: HttpCache, instance_url: str) -> XbrlInstance:
+def parse_xbrl_url(instance_url: str, cache: HttpCache) -> XbrlInstance:
     """
     Parses a instance file with it's taxonomy
-    :param cache: HttpCache instance
     :param instance_url: url to the instance file (on the internet)
+    :param cache: HttpCache instance
     This function will check, if the instance file is already in the cache and load it from there based on the
     instance_url.
     For EDGAR submissions: Before calling this method; extract the enclosure and copy the files to the cache.
@@ -253,7 +253,19 @@ def parse_xbrl_instance(cache: HttpCache, instance_url: str) -> XbrlInstance:
     :return:
     """
     instance_path: str = cache.cache_file(instance_url)
+    return parse_xbrl(instance_path, cache, instance_url)
 
+
+def parse_xbrl(instance_path: str, cache: HttpCache, instance_url: str or None = None) -> XbrlInstance:
+    """
+    Parses a instance file with it's taxonomy
+    :param instance_path: url to the instance file (on the internet)
+    :param cache: HttpCache instance
+    :param instance_url: optional url to the instance file. Is sometimes necessary if the xbrl filings have their own
+    extension taxonomy. If i.e. a submission from the sec is parsed, the instance file might reference the taxonomy schema
+    with a relative path (since it is in the same directory as the instance file) schemaRef="./aapl-20211231.xsd"
+    :return:
+    """
     root: ET.Element = parse_file(instance_path).getroot()
     # get the link to the taxonomy schema and parse it
     schema_ref: ET.Element = root.find(LINK_NS + 'schemaRef')
@@ -308,7 +320,7 @@ def parse_xbrl_instance(cache: HttpCache, instance_url: str) -> XbrlInstance:
     return XbrlInstance(instance_url, taxonomy, facts, context_dir, unit_dir)
 
 
-def parse_ixbrl_instance(cache: HttpCache, instance_url: str) -> XbrlInstance:
+def parse_ixbrl_url(instance_url: str, cache: HttpCache) -> XbrlInstance:
     """
     Parses a inline XBRL (iXBRL) instance file.
     :param cache: HttpCache instance
@@ -320,8 +332,23 @@ def parse_ixbrl_instance(cache: HttpCache, instance_url: str) -> XbrlInstance:
     :return:
     """
     instance_path: str = cache.cache_file(instance_url)
+    return parse_ixbrl(instance_path, cache, instance_url)
+
+
+def parse_ixbrl(instance_path: str, cache: HttpCache, instance_url: str or None = None) -> XbrlInstance:
     """
-    @warning In contrary to the XBRL-parse method we use here the actual root instead of the root element!!!
+    Parses a inline XBRL (iXBRL) instance file.
+    :param instance_path: path to the submission you want to parse
+    :param cache: HttpCache instance
+    :param instance_url: url to the instance file(on the internet)
+    This function will check, if the instance file is already in the cache and load it from there based on the
+    instance_url.
+    For EDGAR submissions: Before calling this method; extract the enclosure and copy the files to the cache.
+        i.e. Use CacheHelper.extract_edgar_enclosure()
+    :return:
+    """
+    """
+    In contrary to the XBRL-parse method we use here the actual root instead of the root element!!!
     to the .getRoot() is missing. This has the benefit, that we can search the document with absolute xpath expressions
     => in the XBRL-parse function root is ET.Element, here just an instance of ElementTree class!
     """
@@ -336,7 +363,7 @@ def parse_ixbrl_instance(cache: HttpCache, instance_url: str) -> XbrlInstance:
         schema_url = resolve_uri(instance_url, schema_uri)
     else:
         schema_url = schema_uri
-    taxonomy: TaxonomySchema = parse_taxonomy(cache,schema_url)
+    taxonomy: TaxonomySchema = parse_taxonomy(cache, schema_url)
 
     # get all contexts and units
     xbrl_resources: ET.Element = root.find('.//ix:resources', ns_map)
